<?php

/*
  Plugin Name: Enquir3 Testimonial
  Plugin URI:  https://www.enquir3.com/wordpress-testimonial-plugin
  Description: Display Enquir3 Testimonial Overview.
  Author: Enquir3 Ltd
  Author URI: https://www.enquir3.com
  Version: 0.2.0
*/

define('EQ3T_PLUGIN_PATH', dirname(__FILE__) . '/');
define('EQ3T_PLUGIN_BASENAME', basename(__FILE__));

require_once EQ3T_PLUGIN_PATH . 'vendor/enquir3/remsto-client.inc';
require_once EQ3T_PLUGIN_PATH . 'vendor/enquir3/remsto-feedback-client.inc';
require_once EQ3T_PLUGIN_PATH . 'includes/eq3t-settings.inc';
require_once EQ3T_PLUGIN_PATH . 'vendor/enquir3/remsto-client-utils.inc';
require_once EQ3T_PLUGIN_PATH . 'includes/widget-overview.inc';

class EQ3T_Testimonial_Display {

  protected $feedback;
  protected $site_id;

  public function __construct( $conf ) {

    $this->feedback = new RemstoFeedbackClient($conf);
    $this->site_id = $conf['client_id'];
    if ( $this->site_id !== '' ) {
      add_shortcode('enquir3-test', array( $this, 'test' ));
      add_shortcode('enquir3-testimonial', array( $this, 'display_feedback_overview' ));
      add_action('wp_enqueue_scripts', array( $this, 'registerJavascript' ));
      add_action('wp_enqueue_scripts', array( $this, 'registerStyle' ));
      add_action('widgets_init', array( $this, 'registerWidgets' ));
    }
  }


	/**
	 * Activate
	 */
  public static function activate() {
	  // Put things here which need to be done on plugin activation.
  }

  /**
   * Resister plug-in widgets
   *
   * @return void
   */
  public function registerWidgets() {
    register_widget('EQ3T_Display_Overview');
  }

  /**
   * Resister all plug-in java script files
   *
   * @return void
   */
  public function registerJavascript() {
    wp_register_script( 'jquery-jcarousel', plugins_url('/js/jquery.jcarousel.js', __FILE__), array( 'jquery' ));
    wp_register_script( 'eq3t-carousel', plugins_url('/js/eq3t.carousel.js', __FILE__), array( 'jquery' ));
  }

  /**
   * Resister all style sheets
   *
   * @return void
   */
  public function registerStyle() {
    wp_register_style( 'eq3t-overview', plugins_url('/css/remsto_feedback_overview.css', __FILE__ ));
  }


  /**
   * Get feedback client instance
   *
   * @return void
   */
  public function getFeedbackClient() {
    return $this->feedback;
  }

  public function test( $atts ) {

    //$t = 'This is ah k hlklh bit of test text';
    //$output = RemstoClientUtils::truncate_utf8($t, 15, true, true);
    return '';
  }

  /**
   * Display widget via short code
   *
   * @param Array $atts widget settings
   * @return void
   */
  public function display_feedback_overview( $atts ) {

    $atts = shortcode_atts( array(
      'theme' => 'medium',
      'max-char' => 150,
        ),
         $atts
        );


    if ( $atts['theme'] !== 'light' && $atts['theme'] !== 'medium' && $atts['theme'] !== 'dark' ) {
      $atts['theme'] = 'medium';
    }

    ob_start();
    the_widget('EQ3T_Display_Overview', $atts);
    return ob_get_clean();
  }

	/**
	 * Compile output from a template and variables.
	 *
	 * @param string $template_path path to template file.
	 * @param array  $vars array of replacement strings.
	 * @return string HTML output
	 */
	public static function compile_template( $template_path, $vars ) {
		// Start output buffering.
		ob_start();

		// Include the template file.
		include $template_path;

		// End buffering and return its contents.
		return ob_get_clean();
	}

	/**
	 * Compile output from a template and variables.
	 *
	 * @param string $template_path path to template file.
	 * @param array  $vars array of replacement strings.
	 */
	public static function render_template( $template_path, $vars ) {
		$output       = self::compile_template( $template_path, $vars );
		$allowed_html = array(
			'form'     => array(
				'action'  => array(),
				'enctype' => array(),
				'method'  => array(),
			),
			'input'    => array(
				'id'        => array(),
				'class'     => array(),
				'type'      => array(),
				'name'      => array(),
				'value'     => array(),
				'size'      => array(),
				'maxlength' => array(),
				'checked'   => array(),
			),
			'label'    => array(
				'for' => array(),
			),
			'div'      => array(
				'id'      => array(),
				'class'   => array(),
				'style'   => array(),
				'title'   => array(),
				'data-id' => array(),
			),
			'span'     => array(
				'class' => array(),
				'title' => array(),
				'style' => array(),
			),
			'textarea' => array(
				'id'          => array(),
				'name'        => array(),
				'class'       => array(),
				'rows'        => array(),
				'cols'        => array(),
				'placeholder' => array(),
			),
			'img'      => array(
				'src' => array(),
			),
			'h2'       => array(),
			'button'   => array(),
			'p'        => array(),
			'i'        => array(),
			'br'       => array(),
			'ul'       => array(),
			'li'       => array(),
		);
		print wp_kses( $output, $allowed_html );
	}

}

register_activation_hook(__FILE__, array( 'EQ3T_Testimonial_Display', 'activate' ));
add_action('plugins_loaded', 'eq3t_init');


/**
 * Initialise plug-in
 */
function eq3t_init() {
  $eq3t_options = get_option('eq3t_options', array());
  if ( ! $eq3t_options ) {
    eq3t_set_default_options();
    $eq3t_options = get_option('eq3t_options', array());
  }
  $testimonial_display = new EQ3T_Testimonial_Display($eq3t_options);
}
